@@ -16,15 +16,6 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
-#endif
-
 #if CUDA_VERSION >= 12000
    #define cusparseCreateCsrsm2Info(info)
    #define cusparseDestroyCsrsm2Info(info)
