@@ -210,7 +210,7 @@ magma_izamax_native(
         hipblasGetPointerMode(queue->hipblas_handle(), &ptr_mode);
         hipblasSetPointerMode(queue->hipblas_handle(), HIPBLAS_POINTER_MODE_DEVICE);
 
-        hipblasIzamax(queue->hipblas_handle(), length, (const hipblasDoubleComplex*)x, 1, (int*)(ipiv));
+        hipblasIzamax(queue->hipblas_handle(), length, (const hipDoubleComplex*)x, 1, (int*)(ipiv));
         hipLaunchKernelGGL(magma_zpivcast, dim3(1), dim3(1), 0, queue->hip_stream() ,  ipiv );
 
         hipblasSetPointerMode(queue->hipblas_handle(), ptr_mode);
