@@ -13,15 +13,6 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
-#endif
-
 #if CUDA_VERSION >= 12000
   #define CUSPARSE_CSRMV_ALG2 CUSPARSE_SPMV_CSR_ALG2
   #define CUSPARSE_CSRMV_ALG1 CUSPARSE_SPMV_CSR_ALG1
@@ -177,8 +168,8 @@ magma_z_spmv(
                 CHECK_CUSPARSE( hipsparseSetMatIndexBase( descr, HIPSPARSE_INDEX_BASE_ZERO ));
                                  
                 hipsparseZcsrmv( hipsparseHandle,HIPSPARSE_OPERATION_NON_TRANSPOSE,
-                                A.num_rows, A.num_cols, A.nnz, (hipblasDoubleComplex*)&alpha, descr,
-                                (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, (hipblasDoubleComplex*)x.dval, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                                A.num_rows, A.num_cols, A.nnz, (hipDoubleComplex*)&alpha, descr,
+                                (hipDoubleComplex*)A.dval, A.drow, A.dcol, (hipDoubleComplex*)x.dval, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else if ( A.storage_type == Magma_CSC )
             {
@@ -189,8 +180,8 @@ magma_z_spmv(
                 CHECK_CUSPARSE( hipsparseSetMatIndexBase( descr, HIPSPARSE_INDEX_BASE_ZERO ));
                 
                 hipsparseZcsrmv( hipsparseHandle,HIPSPARSE_OPERATION_TRANSPOSE,
-                              A.num_rows, A.num_cols, A.nnz, (hipblasDoubleComplex*)&alpha, descr,
-                              (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, (hipblasDoubleComplex*)x.dval, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                              A.num_rows, A.num_cols, A.nnz, (hipDoubleComplex*)&alpha, descr,
+                              (hipDoubleComplex*)A.dval, A.drow, A.dcol, (hipDoubleComplex*)x.dval, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else if ( A.storage_type == Magma_ELL ) {
                 //printf("using ELLPACKT kernel for SpMV: ");
@@ -256,8 +247,8 @@ magma_z_spmv(
                CHECK_CUSPARSE( hipsparseCreateMatDescr( &descr ));
                hipsparseZbsrmv( hipsparseHandle, dirA,
                    HIPSPARSE_OPERATION_NON_TRANSPOSE, mb, nb, A.numblocks,
-                   (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, A.blocksize, (hipblasDoubleComplex*)x.dval,
-                   (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                   (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol, A.blocksize, (hipDoubleComplex*)x.dval,
+                   (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else {
                 printf("error: format not supported.\n");
@@ -276,8 +267,8 @@ magma_z_spmv(
                     hipsparseZcsrmm(hipsparseHandle,
                                    HIPSPARSE_OPERATION_NON_TRANSPOSE,
                                    A.num_rows,   num_vecs, A.num_cols, A.nnz,
-                                   (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                                   (hipblasDoubleComplex*)x.dval, A.num_cols, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval, A.num_cols);
+                                   (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                                   (hipDoubleComplex*)x.dval, A.num_cols, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval, A.num_cols);
                 } else if ( x.major == MagmaRowMajor) {
                     /*hipsparseZcsrmm2(hipsparseHandle,
                     HIPSPARSE_OPERATION_NON_TRANSPOSE,
@@ -298,8 +289,8 @@ magma_z_spmv(
                         
                         hipsparseZcsrmm( hipsparseHandle,HIPSPARSE_OPERATION_TRANSPOSE,
                                         A.num_rows,   num_vecs, A.num_cols, A.nnz,
-                                        (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                                        (hipblasDoubleComplex*)x.dval, A.num_cols, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval, A.num_cols);
+                                        (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                                        (hipDoubleComplex*)x.dval, A.num_cols, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval, A.num_cols);
                     }
             } else if ( A.storage_type == Magma_SELLP ) {
                 if ( x.major == MagmaRowMajor) {
