@@ -16,15 +16,6 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
-#endif
-
 #if CUDA_VERSION >= 12000
    #define hipsparseCreateCsrsm2Info(info)
    #define hipsparseDestroyCsrsm2Info(info)
@@ -47,18 +38,18 @@
 #define hipsparseZcsrsm_analysis(handle, op, rows, nnz, descrA, dval, drow, dcol, info )         \
     {                                                                                           \
         magmaDoubleComplex alpha = MAGMA_Z_ONE;                                                 \
-        hipblasDoubleComplex *B;                                                                     \
+        hipDoubleComplex *B;                                                                     \
         size_t bufsize;                                                                         \
         void *buf;                                                                              \
         hipsparseSetMatType( descrA, HIPSPARSE_MATRIX_TYPE_GENERAL );                             \
         hipsparseZcsrsm2_bufferSizeExt(handle, 0, op, HIPSPARSE_OPERATION_NON_TRANSPOSE,          \
-                                      rows, 1, nnz, (const hipblasDoubleComplex *)&alpha,            \
+                                      rows, 1, nnz, (const hipDoubleComplex *)&alpha,            \
                                       descrA, dval, drow, dcol,                                 \
                                       B, rows, info, HIPSPARSE_SOLVE_POLICY_NO_LEVEL, &bufsize); \
         if (bufsize > 0)                                                                        \
            magma_malloc(&buf, bufsize);                                                         \
         hipsparseZcsrsm2_analysis(handle, 0, op, HIPSPARSE_OPERATION_NON_TRANSPOSE,               \
-                                 rows, 1, nnz, (const hipblasDoubleComplex *)&alpha,                 \
+                                 rows, 1, nnz, (const hipDoubleComplex *)&alpha,                 \
                                  descrA, dval, drow, dcol,                                      \
                                  B, rows, info, HIPSPARSE_SOLVE_POLICY_NO_LEVEL, buf);           \
         if (bufsize > 0)                                                                        \
