@@ -13,11 +13,6 @@
 #include <hip/hip_runtime.h>  // for CUDA_VERSION
 
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#ifdef MAGMA_HAVE_HIP
-  #define hipblasDoubleComplex hipDoubleComplex
-#endif
-
 
 // todo: check if we need buf later
 #if CUDA_VERSION >= 11000
@@ -1757,9 +1752,9 @@ magma_zmconvert(
             // conversion using CUSPARSE
             hipsparseZcsr2bsr( cusparseHandle, HIPSPARSE_DIRECTION_ROW,
                               A.num_rows, A.num_cols, descr,
-                              (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
+                              (hipDoubleComplex*)A.dval, A.drow, A.dcol,
                               size_b, descr,
-                              (hipblasDoubleComplex*)B->dval, B->drow, B->dcol);
+                              (hipDoubleComplex*)B->dval, B->drow, B->dcol);
         }
         // BCSR to CSR
         else if ( old_format == Magma_BCSR && new_format == Magma_CSR ) {
@@ -1791,9 +1786,9 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZbsr2csr( cusparseHandle, HIPSPARSE_DIRECTION_ROW,
-                              mb, nb, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
+                              mb, nb, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
                               size_b, descr,
-                              (hipblasDoubleComplex*)B->dval, B->drow, B->dcol );
+                              (hipDoubleComplex*)B->dval, B->drow, B->dcol );
         }
         // CSR to CSC
         else if ( old_format == Magma_CSR && new_format == Magma_CSC ) {
@@ -1819,8 +1814,8 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZcsr2csc(cusparseHandle, A.num_rows, A.num_cols, A.nnz,
-                             (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                             (hipblasDoubleComplex*)B->dval, B->drow, B->dcol,
+                             (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                             (hipDoubleComplex*)B->dval, B->drow, B->dcol,
                              HIPSPARSE_ACTION_NUMERIC,
                              HIPSPARSE_INDEX_BASE_ZERO);
         }
@@ -1848,8 +1843,8 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZcsr2csc(cusparseHandle, A.num_cols, A.num_rows, A.nnz,
-                             (hipblasDoubleComplex*)A.dval, A.dcol, A.drow,
-                             (hipblasDoubleComplex*)B->dval, B->dcol, B->drow,
+                             (hipDoubleComplex*)A.dval, A.dcol, A.drow,
+                             (hipDoubleComplex*)B->dval, B->dcol, B->drow,
                              HIPSPARSE_ACTION_NUMERIC,
                              HIPSPARSE_INDEX_BASE_ZERO);
         }
